{
  am_pm_abbreviated => [
    "\N{U+0a2a}\N{U+0a42}.\N{U+0a26}\N{U+0a41}.",
    "\N{U+0a2c}\N{U+0a3e}.\N{U+0a26}\N{U+0a41}.",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "MMM, G y",
    GyMMMEd => "E d MMM, G y",
    GyMMMd => "d MMM, G y",
    GyMd => "d/M/GGGGG y",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd-MM.",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-one" => "MMMM \N{U+0a26}\N{U+0a3e} W \N{U+0a39}\N{U+0a2b}\N{U+0a3c}\N{U+0a24}\N{U+0a3e}",
    "MMMMW-count-other" => "MMMM \N{U+0a26}\N{U+0a3e} W \N{U+0a39}\N{U+0a2b}\N{U+0a3c}\N{U+0a24}\N{U+0a3e}",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "Y \N{U+0a26}\N{U+0a3e} w \N{U+0a39}\N{U+0a2b}\N{U+0a3c}\N{U+0a24}\N{U+0a3e}",
    "yw-count-other" => "Y \N{U+0a26}\N{U+0a3e} w \N{U+0a39}\N{U+0a2b}\N{U+0a3c}\N{U+0a24}\N{U+0a3e}",
  },
  code => "pa-Guru",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+0a38}\N{U+0a4b}\N{U+0a2e}",
    "\N{U+0a2e}\N{U+0a70}\N{U+0a17}\N{U+0a32}",
    "\N{U+0a2c}\N{U+0a41}\N{U+0a71}\N{U+0a27}",
    "\N{U+0a35}\N{U+0a40}\N{U+0a30}",
    "\N{U+0a38}\N{U+0a3c}\N{U+0a41}\N{U+0a71}\N{U+0a15}\N{U+0a30}",
    "\N{U+0a38}\N{U+0a3c}\N{U+0a28}\N{U+0a3f}\N{U+0a71}\N{U+0a1a}\N{U+0a30}",
    "\N{U+0a10}\N{U+0a24}",
  ],
  day_format_narrow => [
    "\N{U+0a38}\N{U+0a4b}",
    "\N{U+0a2e}\N{U+0a70}",
    "\N{U+0a2c}\N{U+0a41}\N{U+0a71}",
    "\N{U+0a35}\N{U+0a40}",
    "\N{U+0a38}\N{U+0a3c}\N{U+0a41}\N{U+0a71}",
    "\N{U+0a38}\N{U+0a3c}",
    "\N{U+0a10}",
  ],
  day_format_wide => [
    "\N{U+0a38}\N{U+0a4b}\N{U+0a2e}\N{U+0a35}\N{U+0a3e}\N{U+0a30}",
    "\N{U+0a2e}\N{U+0a70}\N{U+0a17}\N{U+0a32}\N{U+0a35}\N{U+0a3e}\N{U+0a30}",
    "\N{U+0a2c}\N{U+0a41}\N{U+0a71}\N{U+0a27}\N{U+0a35}\N{U+0a3e}\N{U+0a30}",
    "\N{U+0a35}\N{U+0a40}\N{U+0a30}\N{U+0a35}\N{U+0a3e}\N{U+0a30}",
    "\N{U+0a38}\N{U+0a3c}\N{U+0a41}\N{U+0a71}\N{U+0a15}\N{U+0a30}\N{U+0a35}\N{U+0a3e}\N{U+0a30}",
    "\N{U+0a38}\N{U+0a3c}\N{U+0a28}\N{U+0a3f}\N{U+0a71}\N{U+0a1a}\N{U+0a30}\N{U+0a35}\N{U+0a3e}\N{U+0a30}",
    "\N{U+0a10}\N{U+0a24}\N{U+0a35}\N{U+0a3e}\N{U+0a30}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+0a38}\N{U+0a4b}\N{U+0a2e}",
    "\N{U+0a2e}\N{U+0a70}\N{U+0a17}\N{U+0a32}",
    "\N{U+0a2c}\N{U+0a41}\N{U+0a71}\N{U+0a27}",
    "\N{U+0a35}\N{U+0a40}\N{U+0a30}",
    "\N{U+0a38}\N{U+0a3c}\N{U+0a41}\N{U+0a71}\N{U+0a15}\N{U+0a30}",
    "\N{U+0a38}\N{U+0a3c}\N{U+0a28}\N{U+0a3f}\N{U+0a71}\N{U+0a1a}\N{U+0a30}",
    "\N{U+0a10}\N{U+0a24}",
  ],
  day_stand_alone_narrow => [
    "\N{U+0a38}\N{U+0a4b}",
    "\N{U+0a2e}\N{U+0a70}",
    "\N{U+0a2c}\N{U+0a41}\N{U+0a71}",
    "\N{U+0a35}\N{U+0a40}",
    "\N{U+0a38}\N{U+0a3c}\N{U+0a41}\N{U+0a71}",
    "\N{U+0a38}\N{U+0a3c}",
    "\N{U+0a10}",
  ],
  day_stand_alone_wide => [
    "\N{U+0a38}\N{U+0a4b}\N{U+0a2e}\N{U+0a35}\N{U+0a3e}\N{U+0a30}",
    "\N{U+0a2e}\N{U+0a70}\N{U+0a17}\N{U+0a32}\N{U+0a35}\N{U+0a3e}\N{U+0a30}",
    "\N{U+0a2c}\N{U+0a41}\N{U+0a71}\N{U+0a27}\N{U+0a35}\N{U+0a3e}\N{U+0a30}",
    "\N{U+0a35}\N{U+0a40}\N{U+0a30}\N{U+0a35}\N{U+0a3e}\N{U+0a30}",
    "\N{U+0a38}\N{U+0a3c}\N{U+0a41}\N{U+0a71}\N{U+0a15}\N{U+0a30}\N{U+0a35}\N{U+0a3e}\N{U+0a30}",
    "\N{U+0a38}\N{U+0a3c}\N{U+0a28}\N{U+0a3f}\N{U+0a71}\N{U+0a1a}\N{U+0a30}\N{U+0a35}\N{U+0a3e}\N{U+0a30}",
    "\N{U+0a10}\N{U+0a24}\N{U+0a35}\N{U+0a3e}\N{U+0a30}",
  ],
  era_abbreviated => [
    "\N{U+0a08}. \N{U+0a2a}\N{U+0a42}.",
    "\N{U+0a38}\N{U+0a70}\N{U+0a28}",
  ],
  era_narrow => [
    "\N{U+0a08}.\N{U+0a2a}\N{U+0a42}.",
    "\N{U+0a38}\N{U+0a70}\N{U+0a28}",
  ],
  era_wide => [
    "\N{U+0a08}\N{U+0a38}\N{U+0a35}\N{U+0a40} \N{U+0a2a}\N{U+0a42}\N{U+0a30}\N{U+0a35}",
    "\N{U+0a08}\N{U+0a38}\N{U+0a35}\N{U+0a40} \N{U+0a38}\N{U+0a70}\N{U+0a28}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Punjabi",
  month_format_abbreviated => [
    "\N{U+0a1c}\N{U+0a28}",
    "\N{U+0a2b}\N{U+0a3c}\N{U+0a30}",
    "\N{U+0a2e}\N{U+0a3e}\N{U+0a30}\N{U+0a1a}",
    "\N{U+0a05}\N{U+0a2a}\N{U+0a4d}\N{U+0a30}\N{U+0a48}",
    "\N{U+0a2e}\N{U+0a08}",
    "\N{U+0a1c}\N{U+0a42}\N{U+0a28}",
    "\N{U+0a1c}\N{U+0a41}\N{U+0a32}\N{U+0a3e}",
    "\N{U+0a05}\N{U+0a17}",
    "\N{U+0a38}\N{U+0a24}\N{U+0a70}",
    "\N{U+0a05}\N{U+0a15}\N{U+0a24}\N{U+0a42}",
    "\N{U+0a28}\N{U+0a35}\N{U+0a70}",
    "\N{U+0a26}\N{U+0a38}\N{U+0a70}",
  ],
  month_format_narrow => [
    "\N{U+0a1c}",
    "\N{U+0a2b}\N{U+0a3c}",
    "\N{U+0a2e}\N{U+0a3e}",
    "\N{U+0a05}",
    "\N{U+0a2e}",
    "\N{U+0a1c}\N{U+0a42}",
    "\N{U+0a1c}\N{U+0a41}",
    "\N{U+0a05}",
    "\N{U+0a38}",
    "\N{U+0a05}",
    "\N{U+0a28}",
    "\N{U+0a26}",
  ],
  month_format_wide => [
    "\N{U+0a1c}\N{U+0a28}\N{U+0a35}\N{U+0a30}\N{U+0a40}",
    "\N{U+0a2b}\N{U+0a3c}\N{U+0a30}\N{U+0a35}\N{U+0a30}\N{U+0a40}",
    "\N{U+0a2e}\N{U+0a3e}\N{U+0a30}\N{U+0a1a}",
    "\N{U+0a05}\N{U+0a2a}\N{U+0a4d}\N{U+0a30}\N{U+0a48}\N{U+0a32}",
    "\N{U+0a2e}\N{U+0a08}",
    "\N{U+0a1c}\N{U+0a42}\N{U+0a28}",
    "\N{U+0a1c}\N{U+0a41}\N{U+0a32}\N{U+0a3e}\N{U+0a08}",
    "\N{U+0a05}\N{U+0a17}\N{U+0a38}\N{U+0a24}",
    "\N{U+0a38}\N{U+0a24}\N{U+0a70}\N{U+0a2c}\N{U+0a30}",
    "\N{U+0a05}\N{U+0a15}\N{U+0a24}\N{U+0a42}\N{U+0a2c}\N{U+0a30}",
    "\N{U+0a28}\N{U+0a35}\N{U+0a70}\N{U+0a2c}\N{U+0a30}",
    "\N{U+0a26}\N{U+0a38}\N{U+0a70}\N{U+0a2c}\N{U+0a30}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+0a1c}\N{U+0a28}",
    "\N{U+0a2b}\N{U+0a3c}\N{U+0a30}",
    "\N{U+0a2e}\N{U+0a3e}\N{U+0a30}\N{U+0a1a}",
    "\N{U+0a05}\N{U+0a2a}\N{U+0a4d}\N{U+0a30}\N{U+0a48}",
    "\N{U+0a2e}\N{U+0a08}",
    "\N{U+0a1c}\N{U+0a42}\N{U+0a28}",
    "\N{U+0a1c}\N{U+0a41}\N{U+0a32}\N{U+0a3e}",
    "\N{U+0a05}\N{U+0a17}",
    "\N{U+0a38}\N{U+0a24}\N{U+0a70}",
    "\N{U+0a05}\N{U+0a15}\N{U+0a24}\N{U+0a42}",
    "\N{U+0a28}\N{U+0a35}\N{U+0a70}",
    "\N{U+0a26}\N{U+0a38}\N{U+0a70}",
  ],
  month_stand_alone_narrow => [
    "\N{U+0a1c}",
    "\N{U+0a2b}\N{U+0a3c}",
    "\N{U+0a2e}\N{U+0a3e}",
    "\N{U+0a05}",
    "\N{U+0a2e}",
    "\N{U+0a1c}\N{U+0a42}",
    "\N{U+0a1c}\N{U+0a41}",
    "\N{U+0a05}",
    "\N{U+0a38}",
    "\N{U+0a05}",
    "\N{U+0a28}",
    "\N{U+0a26}",
  ],
  month_stand_alone_wide => [
    "\N{U+0a1c}\N{U+0a28}\N{U+0a35}\N{U+0a30}\N{U+0a40}",
    "\N{U+0a2b}\N{U+0a3c}\N{U+0a30}\N{U+0a35}\N{U+0a30}\N{U+0a40}",
    "\N{U+0a2e}\N{U+0a3e}\N{U+0a30}\N{U+0a1a}",
    "\N{U+0a05}\N{U+0a2a}\N{U+0a4d}\N{U+0a30}\N{U+0a48}\N{U+0a32}",
    "\N{U+0a2e}\N{U+0a08}",
    "\N{U+0a1c}\N{U+0a42}\N{U+0a28}",
    "\N{U+0a1c}\N{U+0a41}\N{U+0a32}\N{U+0a3e}\N{U+0a08}",
    "\N{U+0a05}\N{U+0a17}\N{U+0a38}\N{U+0a24}",
    "\N{U+0a38}\N{U+0a24}\N{U+0a70}\N{U+0a2c}\N{U+0a30}",
    "\N{U+0a05}\N{U+0a15}\N{U+0a24}\N{U+0a42}\N{U+0a2c}\N{U+0a30}",
    "\N{U+0a28}\N{U+0a35}\N{U+0a70}\N{U+0a2c}\N{U+0a30}",
    "\N{U+0a26}\N{U+0a38}\N{U+0a70}\N{U+0a2c}\N{U+0a30}",
  ],
  name => "Punjabi Gurmukhi",
  native_language => "\N{U+0a2a}\N{U+0a70}\N{U+0a1c}\N{U+0a3e}\N{U+0a2c}\N{U+0a40}",
  native_name => "\N{U+0a2a}\N{U+0a70}\N{U+0a1c}\N{U+0a3e}\N{U+0a2c}\N{U+0a40} \N{U+0a17}\N{U+0a41}\N{U+0a30}\N{U+0a2e}\N{U+0a41}\N{U+0a16}\N{U+0a40}",
  native_script => "\N{U+0a17}\N{U+0a41}\N{U+0a30}\N{U+0a2e}\N{U+0a41}\N{U+0a16}\N{U+0a40}",
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}1",
    "\N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}2",
    "\N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}3",
    "\N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+0a2a}\N{U+0a39}\N{U+0a3f}\N{U+0a32}\N{U+0a40} \N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}",
    "\N{U+0a26}\N{U+0a42}\N{U+0a1c}\N{U+0a40} \N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}",
    "\N{U+0a24}\N{U+0a40}\N{U+0a1c}\N{U+0a40} \N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}",
    "\N{U+0a1a}\N{U+0a4c}\N{U+0a25}\N{U+0a40} \N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}1",
    "\N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}2",
    "\N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}3",
    "\N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+0a2a}\N{U+0a39}\N{U+0a3f}\N{U+0a32}\N{U+0a40} \N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}",
    "\N{U+0a26}\N{U+0a42}\N{U+0a1c}\N{U+0a40} \N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}",
    "\N{U+0a24}\N{U+0a40}\N{U+0a1c}\N{U+0a40} \N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}",
    "\N{U+0a1a}\N{U+0a4c}\N{U+0a25}\N{U+0a40} \N{U+0a24}\N{U+0a3f}\N{U+0a2e}\N{U+0a3e}\N{U+0a39}\N{U+0a40}",
  ],
  script => "Gurmukhi",
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 41,
}
